* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Dashboards](https://help.sap.com/docs/leanix/ea/dashboards)
  * Application Portfolio Management Dashboard
